import { EndpointParameterInstructions } from "@aws-sdk/middleware-endpoint";
import { Command as $Command } from "@aws-sdk/smithy-client";
import { Handler, HttpHandlerOptions as __HttpHandlerOptions, MetadataBearer as __MetadataBearer, MiddlewareStack } from "@aws-sdk/types";
import { EC2ClientResolvedConfig, ServiceInputTypes, ServiceOutputTypes } from "../EC2Client";
import { ListSnapshotsInRecycleBinRequest, ListSnapshotsInRecycleBinResult } from "../models/models_6";
/**
 * @public
 *
 * The input for {@link ListSnapshotsInRecycleBinCommand}.
 */
export interface ListSnapshotsInRecycleBinCommandInput extends ListSnapshotsInRecycleBinRequest {
}
/**
 * @public
 *
 * The output of {@link ListSnapshotsInRecycleBinCommand}.
 */
export interface ListSnapshotsInRecycleBinCommandOutput extends ListSnapshotsInRecycleBinResult, __MetadataBearer {
}
/**
 * @public
 * <p>Lists one or more snapshots that are currently in the Recycle Bin.</p>
 * @example
 * Use a bare-bones client and the command you need to make an API call.
 * ```javascript
 * import { EC2Client, ListSnapshotsInRecycleBinCommand } from "@aws-sdk/client-ec2"; // ES Modules import
 * // const { EC2Client, ListSnapshotsInRecycleBinCommand } = require("@aws-sdk/client-ec2"); // CommonJS import
 * const client = new EC2Client(config);
 * const input = { // ListSnapshotsInRecycleBinRequest
 *   MaxResults: Number("int"),
 *   NextToken: "STRING_VALUE",
 *   SnapshotIds: [ // SnapshotIdStringList
 *     "STRING_VALUE",
 *   ],
 *   DryRun: true || false,
 * };
 * const command = new ListSnapshotsInRecycleBinCommand(input);
 * const response = await client.send(command);
 * ```
 *
 * @param ListSnapshotsInRecycleBinCommandInput - {@link ListSnapshotsInRecycleBinCommandInput}
 * @returns {@link ListSnapshotsInRecycleBinCommandOutput}
 * @see {@link ListSnapshotsInRecycleBinCommandInput} for command's `input` shape.
 * @see {@link ListSnapshotsInRecycleBinCommandOutput} for command's `response` shape.
 * @see {@link EC2ClientResolvedConfig | config} for EC2Client's `config` shape.
 *
 *
 */
export declare class ListSnapshotsInRecycleBinCommand extends $Command<ListSnapshotsInRecycleBinCommandInput, ListSnapshotsInRecycleBinCommandOutput, EC2ClientResolvedConfig> {
    readonly input: ListSnapshotsInRecycleBinCommandInput;
    static getEndpointParameterInstructions(): EndpointParameterInstructions;
    /**
     * @public
     */
    constructor(input: ListSnapshotsInRecycleBinCommandInput);
    /**
     * @internal
     */
    resolveMiddleware(clientStack: MiddlewareStack<ServiceInputTypes, ServiceOutputTypes>, configuration: EC2ClientResolvedConfig, options?: __HttpHandlerOptions): Handler<ListSnapshotsInRecycleBinCommandInput, ListSnapshotsInRecycleBinCommandOutput>;
    /**
     * @internal
     */
    private serialize;
    /**
     * @internal
     */
    private deserialize;
}
